@@ -16,7 +16,7 @@ from pytorch_optimizer.types import (
 
 class AdamP(Optimizer):
     """
-    Reference : https://github.com/clovaai/AdamP/blob/master/adamp/adamp.py
+    Reference : https://github.com/clovaai/AdamP
     Example :
         from pytorch_optimizer import AdamP
         ...
@@ -42,14 +42,19 @@ class AdamP(Optimizer):
         nesterov: bool = False,
     ):
         """
-        :param params: PARAMS. iterable of parameters to optimize or dicts defining parameter groups
+        :param params: PARAMS. iterable of parameters to optimize
+            or dicts defining parameter groups
         :param lr: float. learning rate.
-        :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace
-        :param eps: float. term added to the denominator to improve numerical stability
+        :param betas: BETAS. coefficients used for computing running averages
+            of gradient and the squared hessian trace
+        :param eps: float. term added to the denominator
+            to improve numerical stability
         :param weight_decay: float. weight decay (L2 penalty)
-        :param delta: float. threshold that determines whether a set of parameters is scale invariant or not
-        :param wd_ratio: float. relative weight decay applied on scale-invariant parameters compared to that applied
-                                on scale-variant parameters
+        :param delta: float. threshold that determines
+            whether a set of parameters is scale invariant or not
+        :param wd_ratio: float. relative weight decay applied
+            on scale-invariant parameters compared to that applied
+            on scale-variant parameters
         :param nesterov: bool. enables Nesterov momentum
         """
 
